<?php

/**
 * @file
 * Media: Kaltura theme functions.
 */

/**
 * Add variables to Media: Kaltura templates.
 */
function media_kaltura_preprocess(&$variables, $hook) {

  // Add general variables to all Kaltura media.
  switch ($hook) {
    case 'media_kaltura__video_dynamic';
    case 'media_kaltura__video_auto';
    case 'media_kaltura__video_thumbnail';
    case 'media_kaltura__video_responsive';
    case 'media_kaltura__audio_dynamic';
    case 'media_kaltura__audio_auto';
    case 'media_kaltura__audio_thumbnail';
    case 'media_kaltura__audio_responsive';
    case 'media_kaltura__video_iframe';
    case 'media_kaltura__audio_iframe';
      $file = $variables['file'];
      $wrapper = file_stream_wrapper_get_instance_by_uri($file->uri);
      $parameters = $wrapper->get_parameters();
      $options = $variables['options'];

      // Set KS session if applicable.
      $variables['session'] = FALSE;
      if ($options['session'] && $session = media_kaltura_ks($wrapper)) {
        $variables['session'] = $session;
      }

      // Set title if applicable.
      $variables['title'] = FALSE;
      if ($options['title']) {
        $variables['title'] = $file->filename;
      }

      // Set title if applicable.
      $variables['logo'] = 'false';
      if ($options['logo']) {
        $variables['logo'] = 'true';
        $variables['logo_img'] = theme_get_setting('logo');
        $variables['logo_href'] = $GLOBALS['base_url'];
        $variables['logo_title'] = variable_get('site_name');
      }

      // Set required variables.
      $variables['domain'] = $parameters['domain'];
      $variables['partner_id'] = $parameters['partner_id'];
      $variables['subpartner_id'] = $parameters['subpartner_id'];
      $variables['uiconf_id'] = $parameters['uiconf_id'];
      $variables['entry_id'] = $parameters['entry_id'];
      $variables['player_id'] = uniqid('kaltura_player_');
      $variables['width'] = $options['width'];
      $variables['height'] = $options['height'];
      $variables['autoplay'] = $options['autoplay'] ? 'true' : 'false';

      // Adds fix for kaltura.com using a separate domain name for ssl.
      // TODO: Find a more elegant way to choose http or https.
      $parse_url = parse_url($GLOBALS['base_url']);
      if ($variables['domain'] === 'cdnapi.kaltura.com' && $parse_url['scheme'] === 'https') {
        $variables['domain'] = 'cdnapisec.kaltura.com';
      }
      break;
  }

  // Add iFrame specific variables.
  switch ($hook) {
    case 'media_kaltura__video_iframe';
    case 'media_kaltura__audio_iframe';
      $variables['src'] = '//' . $variables['domain'];
      $variables['src'] .= '/p/' . $variables['partner_id'];
      $variables['src'] .= '/sp/' . $variables['subpartner_id'];
      $variables['src'] .= '/embedIframeJs';
      $variables['src'] .= '/uiconf_id/' . $variables['uiconf_id'];
      $variables['src'] .= '/partner_id/' . $variables['partner_id'];
      $variables['src'] .= '?iframeembed=true';
      $variables['src'] .= '&playerId=' . $variables['player_id'];
      $variables['src'] .= '&entry_id=' . $variables['entry_id'];
      $variables['src'] .= '&flashvars[autoPlay]=' . $variables['autoplay'];
      $variables['src'] .= '&flashvars[streamerType]=auto';
      $variables['src'] .= '&flashvars[forceMobileHTML5]=true';

      // Add logo to src url.
      if ($options['logo']) {
        $variables['src'] .= '&flashvars[logo.plugin]=true';
        $variables['src'] .= '&flashvars[logo.img]=' . $variables['logo_img'];
        $variables['src'] .= '&flashvars[logo.href]=' . $variables['logo_href'];
        $variables['src'] .= '&flashvars[logo.title]=' . $variables['logo_title'];
      }

      // Add title to src url.
      if ($options['title']) {
        $variables['src'] .= '&flashvars[titleLabel.plugin]=true';
        $variables['src'] .= '&flashvars[titleLabel.text]=' . $variables['title'];
      }

      // Add session to src url.
      if ($options['session']) {
        $variables['src'] .= '&flashvars[ks]=' . $variables['session'];
      }

      break;
  }
}

/**
 * Helper function that starts a KS session if applicable.
 */
function media_kaltura_ks($wrapper) {
  $parameters = $wrapper->get_parameters();

  // Get KS session information if API feature is enabled.
  $id = db_query('SELECT id FROM {media_kaltura_server} WHERE partner_id = :partner_id AND subpartner_id = :subpartner_id AND api = 1', array(':partner_id' => $parameters['partner_id'], ':subpartner_id' => $parameters['subpartner_id']))->fetchField();
  if ($id) {
    try {

      // Check that server exists.
      $server = media_kaltura_server_load($id);
      if (!$server) {
        throw new Exception('Unable to load Kaltura server.');
      }

      // Start a new session with the Kaltura server.
      $kaltura = media_kaltura_start_session($server, $parameters['entry_id']);
      if (!$kaltura) {
        throw new Exception('Unable to start Kaltura session.');
      }

      // Set KS session.
      return $kaltura['ksession'];
    }
    catch (Exception $e) {
      watchdog('media_kaltura', $e->getMessage(), WATCHDOG_ERROR);
    }
  }

  return FALSE;
}
